@@ -2,8 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 from trytond.pool import Pool
 
-from . import account
-from . import sale
+from . import account, sale
 
 
 def register():
