@@ -31,9 +31,12 @@ class Sale(metaclass=PoolMeta):
                 ('kind', '=', 'receivable'),
                 ('kind', '=', 'payable'),
                 ),
-            ('party', '=', If(Bool(Eval('invoice_party')),
-                    Eval('invoice_party'), Eval('party'))),
-            ('currency', '=', Eval('currency')),
+            ['OR',
+                ('party', '=', If(Bool(Eval('invoice_party')),
+                        Eval('invoice_party', -1), Eval('party', -1))),
+                ('state', '!=', 'draft'),
+                ],
+            ('currency', '=', Eval('currency', -1)),
             ],
         states={
             'readonly': Eval('state') != 'quotation',
